%global pkg_name parsec

%global common_summary Haskell parser library

%global common_description Parsec is an industrial-strength parser library.\
It is simple, safe, well documented, has extensive libraries and\
good error messages, and is also fast. It is defined as a monad transformer\
that can be stacked on arbitrary monads, and it is also parametric\
in the input stream type.

%bcond_without doc
%bcond_without prof
%bcond_without shared

# ghc does not emit debug information
%global debug_package %{nil}

Name:           ghc-%{pkg_name}
Version:        2.1.0.1
Release:        1%{?dist}
Summary:        %{common_summary}

Group:          System Environment/Libraries
License:        BSD
URL:            http://hackage.haskell.org/cgi-bin/hackage-scripts/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
# fedora ghc archs:
ExclusiveArch:  %{ix86} x86_64 ppc alpha
BuildRequires:  ghc, ghc-rpm-macros >= 0.4.0
%if %{with doc}
BuildRequires:  ghc-doc
%endif
%if %{with prof}
BuildRequires:  ghc-prof
%endif

%description
%{common_description}

This package provides the shared library.


%package devel
Summary:        %{common_summary} development files
Group:          Development/Libraries
%{?ghc_requires}

%description devel
%{common_description}

This package contains the development files.


%if %{with doc}
%package doc
Summary:        Documentation for %{common_summary}
Group:          Development/Libraries
%{?ghc_doc_requires}

%description doc
%{common_description}

This package contains development documentation files.
%endif


%if %{with prof}
%package prof
Summary:        Profiling libraries for %{common_summary}
Group:          Development/Libraries
%{?ghc_prof_requires}

%description prof
%{common_description}

This package contains the profiling library.
%endif


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%cabal_configure --ghc %{?with_prof:-p}
%cabal build
%if %{with doc}
%cabal haddock
%endif


%install
%cabal_install
%cabal_pkg_conf

%ghc_gen_filelists %{name}


%clean
rm -rf $RPM_BUILD_ROOT


%post devel
ghc-pkg recache


%if %{with doc}
%post doc
%ghc_reindex_haddock
%endif


%postun devel
ghc-pkg recache


%if %{with doc}
%postun doc
if [ "$1" -eq 0 ] ; then
  %ghc_reindex_haddock
fi
%endif


%if %{with shared}
%files -f %{name}.files
%defattr(-,root,root,-)
%{_docdir}/%{name}-%{version}
%endif


%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%if %{without shared}
%{_docdir}/%{name}-%{version}
%endif


%if %{with doc}
%files doc -f %{name}-doc.files
%defattr(-,root,root,-)
%endif


%if %{with prof}
%files prof -f %{name}-prof.files
%defattr(-,root,root,-)
%endif


%changelog
* Thu Dec 24 2009 Jens Petersen <petersen@redhat.com> - 2.1.0.1-1
- update packaging for ghc-6.12.1
- added shared library support
- use new ghc*_requires macros: needs ghc-rpm-macros 0.4.0

* Wed Dec 23 2009 Fedora Haskell SIG <fedora-haskell-list@redhat.com> - 2.1.0.1-0
- initial packaging for Fedora automatically generated by cabal2spec-0.19
